==> content_synchronizer-8.x-1.1.tar.gz: content_synchronizer/src/Service/EntityExportFormBuilder.php <==
<?php

namespace Drupal\content_synchronizer\Service;

use Drupal\content_synchronizer\Entity\ExportEntity;
use Drupal\content_synchronizer\Processors\BatchExportProcessor;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\content_synchronizer\Processors\ExportEntityWriter;
use Drupal\search_api\Plugin\search_api\datasource\ContentEntity;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * The entity export form builder.
 */
class EntityExportFormBuilder {

  const SERVICE_NAME = "content_synchronizer.entity_export_form_builder";
  const ARCHIVE_PARAMS = 'archive';

  /**
   * The export Manager.
   *
   * @var ExportManager
   */
  protected $exportManager;

  /**
   * The current url.
   *
   * @var \Drupal\Core\Url
   */
  protected $currentUrl;

  /**
   * {@inheritdoc}
   */
  public function __construct() {
    $this->exportManager = \Drupal::service(ExportManager::SERVICE_NAME);
  }

  /**
   * Add the export submform in the entity edition form, if the entity is exportable.
   */
  public function addExportFields(array &$form, FormStateInterface $formState) {
    if ($this->isEntityEditForm($form, $formState)) {
      $this->addExportFieldsToEntityForm($form, $formState);
    }
  }

  /**
   * Return true if the form needs to have an export field.
   *
   * @param array $form
   *   The form build array.
   * @param \Drupal\Core\Form\FormStateInterface $formState
   *   The formState array.
   *
   * @return bool
   *   The result.
   */
  protected function isEntityEditForm(array &$form, FormStateInterface $formState) {
    /** @var \Drupal\Core\Entity\EntityForm $formObject */
    $formObject = $formState->getFormObject();

    if ($formObject instanceof EntityForm) {
      if (in_array($formObject->getOperation(), ['edit', 'default'])) {
        $entity = $formObject->getEntity();
        if (strpos(get_class($entity), 'content_synchronizer') === FALSE) {
          if ($objectId = $entity->id()) {
            return isset($objectId);
          }
        }
      }
    }

    return FALSE;
  }

  /**
   * Add exports fields to the entity form.
   *
   * @param array $form
   *   The form build array.
   * @param \Drupal\Core\Form\FormStateInterface $formState
   *   The form state.
   */
  protected function addExportFieldsToEntityForm(array &$form, FormStateInterface $formState) {
    $entity = $formState->getFormObject()->getEntity();

    if ($entity instanceof ContentEntityBase) {
      $form['content_synchronizer'] = [
        '#type'  => 'details',
        '#title' => t('Export'),
        '#group' => 'advanced',
      ];

      $form['content_synchronizer']['quick_export'] = [
        '#type'        => 'submit',
        '#value'       => t('Export entity'),
        '#description' => t('Download the entity .zip file with dependencies'),
        '#button_type' => 'primary',
        '#submit'      => [[$this, 'onQuickExport']],
      ];

      $exportsListOptions = $this->exportManager->getExportsListOptions();
      if (!empty($exportsListOptions)) {
        $form['content_synchronizer']['exports_list'] = [
          '#type'          => 'checkboxes',
          '#title'         => t('Or add the entity to an existing export'),
          '#options'       => $exportsListOptions,
          '#default_value' => array_keys($this->exportManager->getEntitiesExport($entity)),
        ];

        $form['content_synchronizer']['add_to_export'] = [
          '#type'   => 'submit',
          '#value'  => t('Add to the choosen export'),
          '#submit' => [get_called_class() . '::onAddToExport'],
        ];
      }
    }
  }

  /**
   * Action on quick export submit action.
   *
   * @param array $form
   *   The form build array.
   * @param \Drupal\Core\Form\FormStateInterface $formState
   *   The form state.
   */
  public function onQuickExport(array &$form, FormStateInterface $formState) {
    if ($this->isEntityEditForm($form, $formState)) {
      $this->currentUrl = \Drupal::request()->getRequestUri();

      /** @var \Drupal\Core\Entity\Entity $entity */
      $entity = $formState->getFormObject()->getEntity();

      $writer = new ExportEntityWriter();
      $writer->initFromId($entity->getEntityTypeId() . '.' . $entity->id());

      $batchExportProcessor = new BatchExportProcessor($writer);
      $batchExportProcessor->exportEntities([$entity], [$this, 'onBatchEnd']);
    }
  }

  /**
   * On batch end redirect to the form url.
   *
   * @param string $archiveUri
   *   THe archive to download.
   */
  public function onBatchEnd($archiveUri) {
    $redirectUrl = $this->currentUrl;
    \Drupal::service(ArchiveDownloader::SERVICE_NAME)
      ->redirectWithArchivePath($redirectUrl, $archiveUri);
  }

  /**
   * Add entity to an existing entity export.
   *
   * @param array $form
   *   The form build array.
   * @param \Drupal\Core\Form\FormStateInterface $formState
   *   The form state.
   */
  public static function onAddToExport(array &$form, FormStateInterface $formState) {
    $exportsList = ExportEntity::loadMultiple($formState->getValue('exports_list'));
    $entity = $formState->getFormObject()->getEntity();

    /** @var \Drupal\content_synchronizer\Entity\ExportEntity $export */
    foreach (ExportEntity::loadMultiple() as $export) {
      if (array_key_exists($export->id(), $exportsList)) {
        $export->addEntity($entity);
      }
      else {
        $export->removeEntity($entity);
      }
    }

  }

}

==> content_synchronizer-8.x-1.3.tar.gz: content_synchronizer/src/Service/EntityExportFormBuilder.php <==
<?php

namespace Drupal\content_synchronizer\Service;

use Drupal\content_synchronizer\Entity\ExportEntity;
use Drupal\content_synchronizer\Processors\BatchExportProcessor;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\Entity;
use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\content_synchronizer\Processors\ExportEntityWriter;
use Drupal\Core\Url;
use Drupal\search_api\Plugin\search_api\datasource\ContentEntity;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * The entity export form builder.
 */
class EntityExportFormBuilder {

  const SERVICE_NAME = "content_synchronizer.entity_export_form_builder";
  const ARCHIVE_PARAMS = 'archive';

  /**
   * The current url.
   *
   * @var \Drupal\Core\Url
   */
  protected $currentUrl;

  /**
   * Add the export submform in the entity edition form, if the entity is exportable.
   */
  public function addExportFields(array &$form, FormStateInterface $formState) {
    if ($this->isEntityEditForm($form, $formState)) {
      $this->addExportFieldsToEntityForm($form, $formState);
    }
  }

  /**
   * Return true if the form needs to have an export field.
   *
   * @param array $form
   *   The form build array.
   * @param \Drupal\Core\Form\FormStateInterface $formState
   *   The formState array.
   *
   * @return bool
   *   The result.
   */
  protected function isEntityEditForm(array &$form, FormStateInterface $formState) {
    /** @var \Drupal\Core\Entity\EntityForm $formObject */
    $formObject = $formState->getFormObject();

    if ($formObject instanceof EntityForm) {
      if (in_array($formObject->getOperation(), ['edit', 'default'])) {
        $entity = $formObject->getEntity();
        if (strpos(get_class($entity), 'content_synchronizer') === FALSE) {
          if ($objectId = $entity->id()) {
            return isset($objectId);
          }
        }
      }
    }

    return FALSE;
  }

  /**
   * Add exports fields to the entity form.
   *
   * @param array $form
   *   The form build array.
   * @param \Drupal\Core\Form\FormStateInterface $formState
   *   The form state.
   */
  protected function addExportFieldsToEntityForm(array &$form, FormStateInterface $formState) {
    $entity = $formState->getFormObject()->getEntity();

    if ($entity instanceof ContentEntityBase) {
      /** @var ExportManager $exportManager */
      $exportManager = \Drupal::service(ExportManager::SERVICE_NAME);

      $form['content_synchronizer'] = [
        '#type'  => 'details',
        '#title' => t('Export'),
        '#group' => 'advanced',
      ];

      $form['content_synchronizer']['quick_export'] = [
        '#markup' => '<a href="' . $this->getQuickExportUrl($entity) . '" class="button button--primary">' . t('Export entity') . '</a>',
      ];

      $exportsListOptions = $exportManager->getExportsListOptions();
      if (!empty($exportsListOptions)) {
        $form['content_synchronizer']['exports_list'] = [
          '#type'          => 'checkboxes',
          '#title'         => t('Or add the entity to an existing export'),
          '#options'       => $exportsListOptions,
          '#default_value' => array_keys($exportManager->getEntitiesExport($entity)),
        ];

        $form['content_synchronizer']['add_to_export'] = [
          '#type'   => 'submit',
          '#value'  => t('Add to the choosen export'),
          '#submit' => [get_called_class() . '::onAddToExport'],
        ];
      }
    }
  }

  /**
   * Get the batch URL.
   *
   * @param \Drupal\Core\Entity\Entity $entity
   *   THe entity to download.
   *
   * @return string
   *   THe batch url.
   */
  protected function getQuickExportUrl(Entity $entity) {
    $url = Url::fromRoute('content_synchronizer.quick_export');
    $parameters = [
      'destination'  => \Drupal::request()->getRequestUri(),
      'entityTypeId' => $entity->getEntityTypeId(),
      'entityId'     => $entity->id(),
    ];

    return $url->toString() . '?' . http_build_query($parameters);
  }

  /**
   * Add entity to an existing entity export.
   *
   * @param array $form
   *   The form build array.
   * @param \Drupal\Core\Form\FormStateInterface $formState
   *   The form state.
   */
  public static function onAddToExport(array &$form, FormStateInterface $formState) {
    $exportsList = ExportEntity::loadMultiple($formState->getValue('exports_list'));
    $entity = $formState->getFormObject()->getEntity();

    /** @var \Drupal\content_synchronizer\Entity\ExportEntity $export */
    foreach (ExportEntity::loadMultiple() as $export) {
      if (array_key_exists($export->id(), $exportsList)) {
        $export->addEntity($entity);
      }
      else {
        $export->removeEntity($entity);
      }
    }

  }

}
